import sys
import fcntl
import termios
import struct
from ProgressBar import *

def getTerminalSize():
  """
  Return a tuple containing height and width of the current terminal in characters
  """
  height, width = struct.unpack("hhhh", fcntl.ioctl(0, termios.TIOCGWINSZ ,"\000"*8))[0:2]
  return height, width

class TextProgressBar(ProgressBar):
  """
  A simple text rendered version of ProgressBar
  """

  def __init__(self):
    ProgressBar.__init__(self)
    self.length = 60
    self.outFile = sys.stdout
    self.barChar = '='
    self.terminalWidth = getTerminalSize()[1]

  def render(self):
    barLen = self.getBarLen()
    output = '[' + self.barChar * barLen + ' ' * (self.length - barLen) + '] ' + self.formatPercent()
    self.outFile.write(output + ' ' * (self.terminalWidth - len(output)));
    self.outFile.write('\r')
    self.outFile.flush()
    
  def getBarLen(self):
    return int(self.getNormalisedValue() * self.length)

  def fitTerminalWidth(self, rightBorder = 0):
    self.length = self.terminalWidth - 2 - 1 - 3 - 1 - self.precision - 1 - rightBorder
